@@ -3,11 +3,10 @@
 # SPDX-License-Identifier: MIT
 from .__about__ import *
 
-from sleapyfaces.project import Project, Projects
-from sleapyfaces.experiment import Experiment
+from sleapyfaces.types import Experiment, Project, Projects
 from sleapyfaces.io import SLEAPanalysis, DAQData, BehMetadata, VideoMetadata
-from sleapyfaces.structs import File, FileConstructor, CustomColumn
-from sleapyfaces.normalize import mean_center, z_score, pca
+from sleapyfaces.utils.structs import File, FileConstructor, CustomColumn
+from sleapyfaces.utils.normalize import mean_center, z_score, pca, gaussian_kernel
 from sleapyfaces.utils import (
     json_loads,
     json_dumps,
@@ -17,7 +16,6 @@ from sleapyfaces.utils import (
     smooth_diff,
     corr_roll,
     into_trial_format,
-    gaussian_kernel,
     reduce_daq,
 )
 from sleapyfaces.clustering import FeatureExtractor, Cluster
